@@ -8,6 +8,7 @@ from notecoin.okex.database.client import OkexClientAccountBalance
 from notecoin.okex.database.websocket import OkexWebsocketChannels
 from notecoin.okex.websocket.channel import PublicChannel
 from notecoin.okex.websocket.connect import PublicConnect
+from notecoin.okex.websocket.handle import PublicTickers
 
 
 class WebsocketService(APIRouter):
@@ -38,11 +39,11 @@ class WebsocketService(APIRouter):
 
     @api_route('/update/channel', description="get value")
     def update_channels(self):
-
         try:
             res = self.update_channels_db()
 
             new_channels = session.query(OkexWebsocketChannels).all()
+            inst_list = [channel.instId for channel in new_channels]
             new_channels = [eval(channel.channel_json) for channel in new_channels]
 
             old_channels_str = [str(channel) for channel in self.connect.channels]
@@ -53,7 +54,9 @@ class WebsocketService(APIRouter):
                     logging.info(f"old:{old_channels_str},new:{new_channels_str}")
                     self.connect.channels = new_channels
                     self.connect.subscribe_restart()
+
             res["update"] = ["success"]
+            res['inst_list'] = inst_list
         except Exception as e:
             res["update"] = ["failed"]
             res["error"] = str(e)
